@@ -13,6 +13,8 @@ import github
 import json
 import os
 import traceback
+from collections import namedtuple
+from requests.structures import CaseInsensitiveDict
 
 from .utils import create_file, error, log, log_warning
 
@@ -47,6 +49,18 @@ def get_event_info(request):
     return event_info
 
 
+def read_event_from_json(jsonfile):
+    """
+    Read event data from a json file.
+    """
+    req = namedtuple('Request', ['headers', 'json'])
+    with open(jsonfile, 'r') as jf:
+        event_data = json.load(jf)
+        req.headers = CaseInsensitiveDict(event_data['headers'])
+        req.json = event_data['json']
+    return req
+
+
 class PyGHee(flask.Flask):
 
     def __init__(self, *args, **kwargs):
